==> chatroom-2.6.16-sources.jar: com/hummer/im/chatroom/_internals/rpc/RPCCreateChatRoom.java <==
package com.hummer.im.chatroom._internals.rpc;

import android.support.annotation.NonNull;

import com.hummer.im.Error;
import com.hummer.im.HMR;
import com.hummer.im._internals.HMRContext;
import com.hummer.im._internals.yyp.ChatRoomRPC;
import com.hummer.im.chatroom.ChatRoomInfo;
import com.hummer.im._internals.yyp.packet.Marshallable;
import com.hummer.im._internals.yyp.packet.Uint32;
import com.hummer.im._internals.yyp.packet.Uint64;
import com.hummer.im.chatroom._internals.proto.ChatRoomProto;
import com.hummer.im.model.completion.RichCompletionArg;
import com.hummer.im.model.id.ChatRoom;
import com.hummer.im.model.completion.CompletionUtils;

import static com.hummer.im.chatroom.ChatRoomInfo.BasicInfoType.AppExtra;
import static com.hummer.im.chatroom.ChatRoomInfo.BasicInfoType.Bulletin;
import static com.hummer.im.chatroom.ChatRoomInfo.BasicInfoType.Description;
import static com.hummer.im.chatroom.ChatRoomInfo.BasicInfoType.Name;


public class RPCCreateChatRoom extends ChatRoomRPC<ChatRoomProto.PCS_CommonOperatorAuth2Res> {
    public static final String TAG = "RPCCreateChatRoom";

    public RPCCreateChatRoom(ChatRoomInfo chatRoomInfo,
                             RichCompletionArg<ChatRoom> completion) {
        this.chatRoomInfo = chatRoomInfo;
        this.completion = completion;
    }

    @Override
    public String getFunctionName() {
        return "CreateChatRoom";
    }

    @Override
    public String getChatroomServiceName() {
        return "chatroom_auther";
    }

    @Override
    public Marshallable requestObj() {
        ChatRoomProto.PCS_CreateChatRoomReq req = new ChatRoomProto.PCS_CreateChatRoomReq();
        req.appKey = Uint32.toUInt(HMRContext.appId);
        req.uid    = Uint64.toUInt(HMR.getMe().getId());

        if (chatRoomInfo.getName() != null) {
            req.props.put(Name.name(), chatRoomInfo.getName());
        }

        if (chatRoomInfo.getDescription() != null) {
            req.props.put(Description.name(), chatRoomInfo.getDescription());
        }

        if (chatRoomInfo.getBulletin() != null) {
            req.props.put(Bulletin.name(), chatRoomInfo.getBulletin());
        }

        if (chatRoomInfo.getAppExtra() != null) {
            req.props.put(AppExtra.name(), chatRoomInfo.getAppExtra());
        }
        return req;
    }

    @Override
    public void handleSuccess(@NonNull ChatRoomProto.PCS_CommonOperatorAuth2Res res) {
        CompletionUtils.dispatchSuccess(completion, new ChatRoom(res.roomId.longValue()));
    }

    @Override
    public void handleError(@NonNull Error err) {
        CompletionUtils.dispatchFailure(completion, err);
    }

    private final ChatRoomInfo chatRoomInfo;
    private final RichCompletionArg<ChatRoom> completion;
}

==> chatroom-2.6.101-sources.jar: com/hummer/im/chatroom/_internals/rpc/RPCCreateChatRoom.java <==
package com.hummer.im.chatroom._internals.rpc;

import android.support.annotation.NonNull;

import com.hummer.im.Error;
import com.hummer.im.HMR;
import com.hummer.im._internals.HMRContext;
import com.hummer.im.chatroom.ChatRoomInfo;
import com.hummer.im.chatroom._internals.packet.Marshallable;
import com.hummer.im.chatroom._internals.packet.Uint32;
import com.hummer.im.chatroom._internals.packet.Uint64;
import com.hummer.im.chatroom._internals.proto.ChatRoomProto;
import com.hummer.im.model.completion.RichCompletionArg;
import com.hummer.im.model.id.ChatRoom;
import com.hummer.im.model.completion.CompletionUtils;

import static com.hummer.im.chatroom.ChatRoomInfo.BasicInfoType.AppExtra;
import static com.hummer.im.chatroom.ChatRoomInfo.BasicInfoType.Bulletin;
import static com.hummer.im.chatroom.ChatRoomInfo.BasicInfoType.Description;
import static com.hummer.im.chatroom.ChatRoomInfo.BasicInfoType.Name;


public class RPCCreateChatRoom extends ChatRoomRPC<ChatRoomProto.PCS_CommonOperatorAuth2Res> {
    public static final String TAG = "RPCCreateChatRoom";

    public RPCCreateChatRoom(ChatRoomInfo chatRoomInfo,
                             RichCompletionArg<ChatRoom> completion) {
        this.chatRoomInfo = chatRoomInfo;
        this.completion = completion;
    }

    @Override
    public String getFunctionName() {
        return "CreateChatRoom";
    }

    @Override
    public String serviceName() {
        return "chatroom_auther";
    }

    @Override
    public Marshallable requestObj() {
        ChatRoomProto.PCS_CreateChatRoomReq req = new ChatRoomProto.PCS_CreateChatRoomReq();
        req.appKey = Uint32.toUInt(HMRContext.appId);
        req.uid    = Uint64.toUInt(HMR.getMe().getId());

        if (chatRoomInfo.getName() != null) {
            req.props.put(Name.name(), chatRoomInfo.getName());
        }

        if (chatRoomInfo.getDescription() != null) {
            req.props.put(Description.name(), chatRoomInfo.getDescription());
        }

        if (chatRoomInfo.getBulletin() != null) {
            req.props.put(Bulletin.name(), chatRoomInfo.getBulletin());
        }

        if (chatRoomInfo.getAppExtra() != null) {
            req.props.put(AppExtra.name(), chatRoomInfo.getAppExtra());
        }
        return req;
    }

    @Override
    public void handleSuccess(@NonNull ChatRoomProto.PCS_CommonOperatorAuth2Res res) {
        CompletionUtils.dispatchSuccess(completion, new ChatRoom(res.roomId.longValue()));
    }

    @Override
    public void handleError(@NonNull Error err) {
        CompletionUtils.dispatchFailure(completion, err);
    }

    private final ChatRoomInfo chatRoomInfo;
    private final RichCompletionArg<ChatRoom> completion;
}
